// 特效圆
<template>
  <Popup
    ref="pop"
    :title="title"
    :shadow="false"
    :left="left"
    width="310px"
    :showBtn="false"
  >
    <el-form ref="form" :model="data" :rules="rules" label-width="70px">
      <el-form-item label="高度:">
        <el-input-number v-model="data.height"></el-input-number>
      </el-form-item>
      <el-form-item label="绘制:">
        <el-button type="info" size="mini" @click="draw">图上选点</el-button>
      </el-form-item>
    </el-form>
  </Popup>
</template>

<script>
import Popup from "@tools/Popup";
import Bus from "@tools/Bus";
let circle;
export default {
  name: "RotateEffectCircle",
  components: {
    Popup,
  },
  data() {
    return {
      title: "添加特效圆",
      left: "calc(100% - 320px)",
      data: {
        height: 20,
      },
      // 表单验证规则
      rules: {},
      //颜色
    };
  },
  mounted() {},
  methods: {
    // 关闭弹窗
    close() {
      circle && circle.end && circle.end();
      circle = undefined;
      // 重置data值
      Object.assign(this.$data, this.$options.data());
    },
    // 打开弹窗
    open() {
      this.close();
      this.$refs.pop.open();
    },
    draw() {
      this.$refs.form.validate((valid) => {
        // 验证通过
        if (valid) {
          this.$message("在场景内绘制范围添加");
          circle && circle.end && circle.end();
          circle = sgworld.Creator.createSimpleGraphic(
            "circle",
            { color: "rgba(67, 162, 218, 0.6)" },
            (entity, data) => {
              entity.deleteObject();

              // 获取经纬度
              let degrees = sgworld.Core.toDegrees(data.positions[1]);
              this.addRotateEffectCircle(degrees, data.distance);
            }
          );
        }
      });
    },

    addRotateEffectCircle(degrees, radius) {
      degrees.height = this.data.height;
      // 特效圆-旋转
      let rotateEffectCircle = sgworld.Creator.addRotateEffectCircle({
        position: degrees,
        radius: radius,
      });
      // 添加到图层树
      Bus.$emit("addOtherData", "特效", {
        id: sgworld.Core.getuid(),
        name: "新建特效圆",
        sourceType: "rotateEffectCircle",
        position: degrees,
        radius,
        height: this.data.height,
        item: rotateEffectCircle,
      });
    },
  },
};
</script>

<style scoped lang="less">
.el-form {
  margin-top: 20px;
  margin-right: 10px;
  width: 300px;

  /deep/ .el-form-item__label {
    color: #fff;
    font-size: 18px;
  }
}
</style>
